@@ -1,30 +1,28 @@
 # -*- coding: utf-8 -*-
-# (c) YashDK [yash-dk@github]
-# modified by reaitten [reaitten@github]
-# welcome to fucking hell.
+
 
 from telethon import TelegramClient,events 
 from telethon import __version__ as telever
 from pyrogram import __version__ as pyrover
 from telethon.tl.types import KeyboardButtonCallback
-from tgtk.consts.ExecVarsSample import ExecVars
-from tgtk.core.getCommand import get_command
-from tgtk.core.getVars import get_val
-from tgtk.functions.Leech_Module import check_link,cancel_torrent,pause_all,resume_all,purge_all,get_status,print_files, get_transfer
-from tgtk.functions.tele_upload import upload_a_file,upload_handel
-from tgtk.functions import Human_Format
-from tgtk.core.database_handle import tkupload,tktorrents, tkdb
-from tgtk.core.settings import handle_settings,handle_setting_callback
-from tgtk.core.user_settings import handle_user_settings, handle_user_setting_callback
+from ..consts.ExecVarsSample import ExecVars
+from ..core.getCommand import get_command
+from ..core.getVars import get_val
+from ..functions.Leech_Module import check_link,cancel_torrent,pause_all,resume_all,purge_all,get_status,print_files, get_transfer
+from ..functions.tele_upload import upload_a_file,upload_handel
+from ..functions import Human_Format
+from .database_handle import tkupload,tktorrents, tkdb
+from .settings import handle_settings,handle_setting_callback
+from .user_settings import handle_user_settings, handle_user_setting_callback
 from functools import partial
-from tgtk.functions.rclone_upload import get_config, rclone_driver
-from tgtk.functions.admin_check import is_admin
-from tgtk import upload_db,var_db,tor_db,user_db, uptime
+from ..functions.rclone_upload import get_config,rclone_driver
+from ..functions.admin_check import is_admin
+from .. import upload_db, var_db, tor_db, user_db, uptime
 import asyncio as aio
 import re,logging,time,os,psutil,shutil
 from tgtk import __version__
-from tgtk.core.ttk_ytdl import handle_ytdl_command,handle_ytdl_callbacks,handle_ytdl_file_download,handle_ytdl_playlist,handle_ytdl_playlist_down
-from tgtk.functions.instadl import _insta_post_downloader
+from .ttk_ytdl import handle_ytdl_command,handle_ytdl_callbacks,handle_ytdl_file_download,handle_ytdl_playlist,handle_ytdl_playlist_down
+from ..functions.instadl import _insta_post_downloader
 torlog = logging.getLogger(__name__)
 from .status.status import Status
 from .status.menu import create_status_menu, create_status_user_menu
@@ -208,31 +206,34 @@ def add_handlers(bot: TelegramClient):
         handle_user_setting_callback,
         events.CallbackQuery(pattern="usetting")
     )
-    test()
+    bot.add_event_handler(
+        handle_server_command,
+        events.CallbackQuery(pattern="fullserver")
+    )
 #*********** Handlers Below ***********
 
 async def handle_leech_command(e):
     if not e.is_reply:
-        await e.reply("Reply to a link or magnet")
+        await e.reply("reply to a link or magnet.")
     else:
         rclone = False
         tsp = time.time()
-        buts = [[KeyboardButtonCallback("To Telegram",data=f"leechselect tg {tsp}")]]
+        buts = [[KeyboardButtonCallback("to telegram",data=f"leechselect tg {tsp}")]]
         if await get_config() is not None:
             buts.append(
-                [KeyboardButtonCallback("To Drive",data=f"leechselect drive {tsp}")]
+                [KeyboardButtonCallback("to drive",data=f"leechselect drive {tsp}")]
             )
         # tsp is used to split the callbacks so that each download has its own callback
-        # cuz at any time there are 10-20 callbacks linked for leeching (why do people say xd?)
+        # cuz at any time there are 10-20 callbacks linked for leeching XD
            
         buts.append(
-                [KeyboardButtonCallback("Upload in a ZIP.[Toggle]", data=f"leechzip toggle {tsp}")]
+                [KeyboardButtonCallback("upload in a zip.[Toggle]", data=f"leechzip toggle {tsp}")]
         )
         buts.append(
-                [KeyboardButtonCallback("Extract from Archive.[Toggle]", data=f"leechzipex toggleex {tsp}")]
+                [KeyboardButtonCallback("extract from archive.[Toggle]", data=f"leechzipex toggleex {tsp}")]
         )
         
-        conf_mes = await e.reply(f"<b>first click if you want to zip the contents or extract as an archive (only one will work at a time) then, </b>\n<b>choose where to upload your files:- </b>\nthe files will be uploaded to default destination after {get_val('DEFAULT_TIMEOUT')} sec of no action by user.\n\n supported archives to extract are: .zip, 7z, tar, gzip2, iso, wim, rar, tar.gz,tar.bz2",parse_mode="html",buttons=buts)
+        conf_mes = await e.reply(f"<b>first click if you want to zip the contents or extract as an archive (only one will work at a time) then, </b>\n<b>choose where to upload your files: </b>\nthe files will be uploaded to default destination after {get_val('DEFAULT_TIMEOUT')} sec of no action by user.\n\n supported archives to extract are: .zip, 7z, tar, gzip2, iso, wim, rar, tar.gz,tar.bz2",parse_mode="html",buttons=buts)        
         
         # zip check in background
         ziplist = await get_zip_choice(e,tsp)
@@ -275,11 +276,6 @@ async def get_leech_choice(e,timestamp):
     cbak = partial(get_leech_choice_callback,o_sender=e.sender_id,lis=lis,ts=timestamp)
     
     gtyh = ""
-    sam1 = [68, 89, 78, 79]
-    for i in sam1:
-        gtyh += chr(i)
-    if os.environ.get(gtyh,False):
-        os.environ["TIME_STAT"] = str(time.time())
 
     e.client.add_event_handler(
         #lambda e: test_callback(e,lis),
@@ -372,21 +368,6 @@ async def handle_purge_command(e):
     else:
         await e.delete()
 
-def test():
-    herstr = ""
-    sam = [104, 101, 114, 111, 107, 117, 97, 112, 112, 46, 99, 111, 109]
-    sam1 = [68, 89, 78, 79]
-    for i in sam1:
-        herstr += chr(i)
-    if os.environ.get(herstr,False):
-        os.environ["TIME_STAT"] = str(time.time())
-    herstr = ""
-    for i in sam:
-        herstr += chr(i)
-    if os.environ.get("BASE_URL_OF_BOT",False):
-        if herstr.lower() in os.environ.get("BASE_URL_OF_BOT").lower():
-            os.environ["TIME_STAT"] = str(time.time())
-
 async def handle_pauseall_command(e):
     if await is_admin(e.client,e.sender_id,e.chat_id):
         await pause_all(e)
@@ -419,12 +400,10 @@ async def handle_u_status_command(e):
     await create_status_user_menu(e)
         
         
-
 async def handle_test_command(e):
     pass
     
 
-
 async def handle_settings_cb(e):
     if await is_admin(e.client,e.sender_id,e.chat_id):
         await handle_setting_callback(e)
@@ -435,7 +414,7 @@ async def handle_upcancel_cb(e):
     db = upload_db
 
     data = e.data.decode("UTF-8")
-    torlog.info("Data is {}".format(data))
+    torlog.info("data is {}".format(data))
     data = data.split(" ")
 
     if str(e.sender_id) == data[3]:
@@ -451,7 +430,7 @@ async def callback_handler_canc(e):
     #mes = await mes.get_reply_message()
     
 
-    torlog.debug(f"Here the sender _id is {e.sender_id}")
+    torlog.debug(f"the sender id is {e.sender_id}")
     torlog.debug("list bot is authorized on: {} {}".format(get_val("ALD_USR"),type(get_val("ALD_USR"))))
 
     data = e.data.decode("utf-8").split(" ")
@@ -472,7 +451,7 @@ async def callback_handler_canc(e):
         hashid = data[1]
         hashid = hashid.strip("'")
         
-        torlog.info(f"Hashid :- {hashid}")
+        torlog.info(f"Hashid: {hashid}")
         
         await cancel_torrent(hashid, is_aria)
         await e.answer("the download has been canceled by an authorized user.",alert=True)
@@ -524,7 +503,7 @@ async def handle_exec_message_f(e):
         else:
             await message.reply(OUTPUT)
     else:
-        await message.reply("Only for owner")
+        await message.reply("only for owner.")
 
 async def handle_pincode_cb(e):
     data = e.data.decode("UTF-8")
@@ -560,7 +539,7 @@ async def upload_document_f(message):
             )
             #torlog.info(recvd_response)
     else:
-        await message.reply("the owner has the permission to invoke this command.")
+        await message.reply("only for owner.")
     await imsegd.delete()
 
 async def get_logs_f(e):
@@ -589,8 +568,36 @@ async def start_handler(event):
     msg = "TK - A Telegram Leecher Bot."
     await event.reply(msg, parse_mode="html")
 
+def progress_bar(percentage):
+    """Returns a progress bar for download
+    """
+    #percentage is on the scale of 0-1
+    comp = get_val("COMPLETED_STR")
+    ncomp = get_val("REMAINING_STR")
+    pr = ""
+
+    if isinstance(percentage, str):
+        return "NaN"
+
+    try:
+        percentage=int(percentage)
+    except:
+        percentage = 0
+
+    for i in range(1,11):
+        if i <= int(percentage/10):
+            pr += comp
+        else:
+            pr += ncomp
+    return pr
 
 async def handle_server_command(message):
+    print(type(message))
+    if isinstance(message, events.CallbackQuery.Event):
+        callbk = True
+    else:
+        callbk = False
+
     try:
         # Memory
         mem = psutil.virtual_memory()
@@ -649,29 +656,49 @@ async def handle_server_command(message):
     diff = time.time() - uptime
     diff = Human_Format.human_readable_timedelta(diff)
 
-    msg = (
-        f"<b>BOT UPTIME:-</b> {diff}\n\n"
-        "<b>CPU STATS:-</b>\n"
-        f"Cores: {cores} Logical: {lcores}\n"
-        f"CPU Frequency: {freqcurrent}  Mhz Max: {freqmax}\n"
-        f"CPU Utilization: {cpupercent}%\n"
-        "\n"
-        "<b>STORAGE STATS:-</b>\n"
-        f"Total: {totaldsk}\n"
-        f"Used: {useddsk}\n"
-        f"Free: {freedsk}\n"
-        "\n"
-        "<b>MEMORY STATS:-</b>\n"
-        f"Available: {memavailable}\n"
-        f"Total: {memtotal}\n"
-        f"Usage: {mempercent}%\n"
-        f"Free: {memfree}\n"
-        "\n"
-        "<b>TRANSFER INFO:</b>\n"
-        f"Download: {dlb}\n"
-        f"Upload: {upb}\n"
-    )
-    await message.reply(msg, parse_mode="html")
+    if callbk:
+        msg = (
+            f"<b>bot uptime</b> {diff}\n\n"
+            "<b>cpu stats:</b>\n"
+            f"cores: {cores} logical: {lcores}\n"
+            f"cpu frequency: {freqcurrent}  mhz max: {freqmax}\n"
+            f"cpu utilization: {cpupercent}%\n"
+            "\n"
+            "<b>storage stats:</b>\n"
+            f"total: {totaldsk}\n"
+            f"used: {useddsk}\n"
+            f"free: {freedsk}\n"
+            "\n"
+            "<b>memory stats:</b>\n"
+            f"available: {memavailable}\n"
+            f"total: {memtotal}\n"
+            f"usage: {mempercent}%\n"
+            f"free: {memfree}\n"
+            "\n"
+            "<b>transfer info:</b>\n"
+            f"download: {dlb}\n"
+            f"upload: {upb}\n"
+        )
+        await message.edit(msg, parse_mode="html", buttons=None)
+    else:
+        try:
+            storage_percent = round((usage.used/usage.total)*100,2)
+        except:
+            storage_percent = 0
+
+        
+        msg = (
+            f"<b>bot uptime:</b> {diff}\n\n"
+            f"cpu utilization: {progress_bar(cpupercent)} - {cpupercent}%\n\n"
+            f"storage used: {progress_bar(storage_percent)} - {storage_percent}%\n"
+            f"total: {totaldsk} free: {freedsk}\n\n"
+            f"memory used:- {progress_bar(mempercent)} - {mempercent}%\n"
+            f"total: {memtotal} free: {memfree}\n\n"
+            f"transfer download: {dlb}\n"
+            f"transfer upload: {upb}\n"
+        )
+        await message.reply(msg, parse_mode="html", buttons=[[KeyboardButtonCallback("get detailed stats.","fullserver")]])
+
 
 async def about_me(message):
     db = var_db
@@ -679,7 +706,7 @@ async def about_me(message):
     if val1 is None:
         rclone_cfg = "no rclone config is loaded."
     else:
-        rclone_cfg = "rclone config is loaded"
+        rclone_cfg = "rclone config is loaded."
 
     val1  = get_val("RCLONE_ENABLED")
     if val1 is not None:
@@ -692,7 +719,7 @@ async def about_me(message):
 
     val1  = get_val("LEECH_ENABLED")
     if val1 is not None:
-        if val1:
+        if val1: 
             leen = "leech command enabled by admin."
         else:
             leen = "leech command disabled by admin."
@@ -704,20 +731,21 @@ async def about_me(message):
     diff = Human_Format.human_readable_timedelta(diff)
 
     msg = (
-        "<b>Name</b>: <code>TK</code>\n"
-        f"<b>Version</b>: <code>{__version__}</code>\n"
-        f"<b>Telethon Version</b>: {telever}\n"
-        f"<b>Pyrogram Version</b>: {pyrover}\n"
-        f"<u>Currents Configs:-</u>\n\n"
-        f"<b>Bot Uptime:-</b> {diff}\n"
-        f"<b>Torrent Download Engine:-</b> <code>qBittorrent [4.3.0 fix active]</code> \n"
-        f"<b>Direct Link Download Engine:-</b> <code>aria2</code> \n"
-        f"<b>Upload Engine:-</b> <code>rclone</code> \n"
-        f"<b>Youtube Download Engine:-</b> <code>youtube-dl</code>\n"
-        f"<b>Rclone config:- </b> <code>{rclone_cfg}</code>\n"
-        f"<b>Leech:- </b> <code>{leen}</code>\n"
-        f"<b>Rclone:- </b> <code>{rclone}</code>\n"
+        "<b>name</b>: <code>tgtk</code>\n"
+        f"<b>version</b>: <code>{__version__}</code>\n"
+        f"<b>telethon Version</b>: {telever}\n"
+        f"<b>pyrogram Version</b>: {pyrover}\n"
+        "<u>currents configs:</u>\n\n"
+        f"<b>bot uptime:</b> {diff}\n"
+        "<b>torrent download engine:</b> <code>qBittorrent [4.3.0 fix active]</code> \n"
+        "<b>direct link download engine:</b> <code>aria2</code> \n"
+        "<b>upload Engine:</b> <code>rclone</code> \n"
+        "<b>youtube download engine:</b> <code>youtube-dl</code>\n"
+        f"<b>rclone config: </b> <code>{rclone_cfg}</code>\n"
+        f"<b>leech: </b> <code>{leen}</code>\n"
+        f"<b>rclone: </b> <code>{rclone}</code>\n"
     )
+
     await message.reply(msg,parse_mode="html")
 
 
@@ -745,7 +773,7 @@ async def set_thumb_cmd(e):
         os.remove(value)
     except Exception:
         torlog.exception("Set Thumb")
-        await e.reply("An error occured while setting the thumbnail.")
+        await e.reply("an error occurred while setting the thumbnail.")
         return
     
     try:
@@ -784,7 +812,7 @@ def term_handler(signum, frame, client):
                 chat_id = omess.chat_id
             
             sender = await i.get_sender_id()
-            msg += f"<a href='tg://user?id={sender}'>REBOOT</a> - <a href='https://t.me/c/{chat_id}/{omess.id}'>Task</a>\n"
+            msg += f"<a href='tg://user?id={sender}'>reboot</a> - <a href='https://t.me/c/{chat_id}/{omess.id}'>task</a>\n"
         
         if omess is not None:
             await omess.respond(msg, parse_mode="html")
