@@ -1,11 +1,11 @@
 # -*- coding: utf-8 -*-
-# (c) YashDK [yash-dk@github]
+
 
 from urllib.parse import urlparse,parse_qs
 import logging
 from torrentool.api import Torrent
 
-logging.basicConfig(level=logging.DEBUG)
+#logging.basicConfig(level=logging.DEBUG)
 
 def get_hash_magnet(mgt):
     if mgt.startswith('magnet:'):
